@@ -1,6 +1,4 @@
-#ifndef ABSTRACTPLATFORM_H
-#define ABSTRACTPLATFORM_H
-
+#pragma once
 #include <QList>
 #include <QObject>
 #include <QString>
@@ -16,12 +14,12 @@
 class MAUIKIT_EXPORT AbstractPlatform : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(bool darkModeEnabled READ darkModeEnabled NOTIFY darkModeEnabledChanged FINAL)
+    Q_PROPERTY(bool darkModeEnabled READ darkModeEnabled NOTIFY darkModeEnabledChanged)
 
 public:
     explicit AbstractPlatform(QObject *parent = nullptr);
 
-public slots:
+public Q_SLOTS:
 
     /**
      * @brief shareFiles
@@ -49,13 +47,11 @@ public slots:
 
     virtual void notify(const QString &title, const QString &message, const QString &icon, const QString &imageUrl);
 
-    virtual bool darkModeEnabled() =0;
+    virtual bool darkModeEnabled() = 0;
 
-signals:
+Q_SIGNALS:
     void hasKeyboardChanged();
     void hasMouseChanged();
     void shareFilesRequest(QStringList urls);
     void darkModeEnabledChanged();
 };
-
-#endif // ABSTRACTPLATFORM_H
