@@ -17,8 +17,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef FMH_H
-#define FMH_H
+#pragma once
 
 #include <QHash>
 #include <QVariant>
@@ -212,157 +211,157 @@ enum MODEL_KEY : int {
     UPDATABLE
 };
 
-static const QHash<MODEL_KEY, QString> MODEL_NAME = {{MODEL_KEY::ICON, "icon"},
-                                                     {MODEL_KEY::LABEL, "label"},
-                                                     {MODEL_KEY::PATH, "path"},
-                                                     {MODEL_KEY::URL, "url"},
-                                                     {MODEL_KEY::TYPE, "type"},
-                                                     {MODEL_KEY::GROUP, "group"},
-                                                     {MODEL_KEY::OWNER, "owner"},
-                                                     {MODEL_KEY::SUFFIX, "suffix"},
-                                                     {MODEL_KEY::NAME, "name"},
-                                                     {MODEL_KEY::DATE, "date"},
-                                                     {MODEL_KEY::MODIFIED, "modified"},
-                                                     {MODEL_KEY::MIME, "mime"},
-                                                     {MODEL_KEY::SIZE, "size"},
-                                                     {MODEL_KEY::TAG, "tag"},
-                                                     {MODEL_KEY::PERMISSIONS, "permissions"},
-                                                     {MODEL_KEY::THUMBNAIL, "thumbnail"},
-                                                     {MODEL_KEY::THUMBNAIL_1, "thumbnail_1"},
-                                                     {MODEL_KEY::THUMBNAIL_2, "thumbnail_2"},
-                                                     {MODEL_KEY::THUMBNAIL_3, "thumbnail_3"},
-                                                     {MODEL_KEY::ICONSIZE, "iconsize"},
-                                                     {MODEL_KEY::HIDDEN, "hidden"},
-                                                     {MODEL_KEY::DETAILVIEW, "detailview"},
-                                                     {MODEL_KEY::SHOWTERMINAL, "showterminal"},
-                                                     {MODEL_KEY::SHOWTHUMBNAIL, "showthumbnail"},
-                                                     {MODEL_KEY::COUNT, "count"},
-                                                     {MODEL_KEY::SORTBY, "sortby"},
-                                                     {MODEL_KEY::USER, "user"},
-                                                     {MODEL_KEY::PASSWORD, "password"},
-                                                     {MODEL_KEY::SERVER, "server"},
-                                                     {MODEL_KEY::FOLDERSFIRST, "foldersfirst"},
-                                                     {MODEL_KEY::VIEWTYPE, "viewtype"},
-                                                     {MODEL_KEY::ADDDATE, "adddate"},
-                                                     {MODEL_KEY::FAV, "fav"},
-                                                     {MODEL_KEY::FAVORITE, "favorite"},
-                                                     {MODEL_KEY::COLOR, "color"},
-                                                     {MODEL_KEY::RATE, "rate"},
-                                                     {MODEL_KEY::FORMAT, "format"},
-                                                     {MODEL_KEY::PLACE, "place"},
-                                                     {MODEL_KEY::LOCATION, "location"},
-                                                     {MODEL_KEY::ALBUM, "album"},
-                                                     {MODEL_KEY::DURATION, "duration"},
-                                                     {MODEL_KEY::RELEASEDATE, "releasedate"},
-                                                     {MODEL_KEY::ARTIST, "artist"},
-                                                     {MODEL_KEY::LYRICS, "lyrics"},
-                                                     {MODEL_KEY::TRACK, "track"},
-                                                     {MODEL_KEY::GENRE, "genre"},
-                                                     {MODEL_KEY::WIKI, "wiki"},
-                                                     {MODEL_KEY::CONTEXT, "context"},
-                                                     {MODEL_KEY::SOURCETYPE, "sourcetype"},
-                                                     {MODEL_KEY::ARTWORK, "artwork"},
-                                                     {MODEL_KEY::NOTE, "note"},
-                                                     {MODEL_KEY::MOOD, "mood"},
-                                                     {MODEL_KEY::COMMENT, "comment"},
-                                                     {MODEL_KEY::PLAYLIST, "playlist"},
-                                                     {MODEL_KEY::SOURCE, "source"},
-                                                     {MODEL_KEY::TITLE, "title"},
-                                                     {MODEL_KEY::ID, "id"},
-                                                     {MODEL_KEY::PERSON_ID, "personid"},
-                                                     {MODEL_KEY::PARENT_ID, "parentid"},
-                                                     {MODEL_KEY::LICENSE, "license"},
-                                                     {MODEL_KEY::DESCRIPTION, "description"},
-                                                     {MODEL_KEY::BOOKMARK, "bookmark"},
-                                                     {MODEL_KEY::ACCOUNT, "account"},
-                                                     {MODEL_KEY::ACCOUNTTYPE, "accounttype"},
-                                                     {MODEL_KEY::VERSION, "version"},
-                                                     {MODEL_KEY::DOMAIN_M, "domain"},
-                                                     {MODEL_KEY::CATEGORY, "category"},
-                                                     {MODEL_KEY::CONTENT, "content"},
-                                                     {MODEL_KEY::PIN, "pin"},
-                                                     {MODEL_KEY::IMG, "img"},
-                                                     {MODEL_KEY::PREVIEW, "preview"},
-                                                     {MODEL_KEY::LINK, "link"},
-                                                     {MODEL_KEY::STAMP, "stamp"},
-                                                     {MODEL_KEY::BOOK, "book"},
+static const QHash<MODEL_KEY, QString> MODEL_NAME = {{MODEL_KEY::ICON, QStringLiteral("icon")},
+                                                     {MODEL_KEY::LABEL, QStringLiteral("label")},
+                                                     {MODEL_KEY::PATH, QStringLiteral("path")},
+                                                     {MODEL_KEY::URL, QStringLiteral("url")},
+                                                     {MODEL_KEY::TYPE, QStringLiteral("type")},
+                                                     {MODEL_KEY::GROUP, QStringLiteral("group")},
+                                                     {MODEL_KEY::OWNER, QStringLiteral("owner")},
+                                                     {MODEL_KEY::SUFFIX, QStringLiteral("suffix")},
+                                                     {MODEL_KEY::NAME, QStringLiteral("name")},
+                                                     {MODEL_KEY::DATE, QStringLiteral("date")},
+                                                     {MODEL_KEY::MODIFIED, QStringLiteral("modified")},
+                                                     {MODEL_KEY::MIME, QStringLiteral("mime")},
+                                                     {MODEL_KEY::SIZE, QStringLiteral("size")},
+                                                     {MODEL_KEY::TAG, QStringLiteral("tag")},
+                                                     {MODEL_KEY::PERMISSIONS, QStringLiteral("permissions")},
+                                                     {MODEL_KEY::THUMBNAIL, QStringLiteral("thumbnail")},
+                                                     {MODEL_KEY::THUMBNAIL_1, QStringLiteral("thumbnail_1")},
+                                                     {MODEL_KEY::THUMBNAIL_2, QStringLiteral("thumbnail_2")},
+                                                     {MODEL_KEY::THUMBNAIL_3, QStringLiteral("thumbnail_3")},
+                                                     {MODEL_KEY::ICONSIZE, QStringLiteral("iconsize")},
+                                                     {MODEL_KEY::HIDDEN, QStringLiteral("hidden")},
+                                                     {MODEL_KEY::DETAILVIEW, QStringLiteral("detailview")},
+                                                     {MODEL_KEY::SHOWTERMINAL, QStringLiteral("showterminal")},
+                                                     {MODEL_KEY::SHOWTHUMBNAIL, QStringLiteral("showthumbnail")},
+                                                     {MODEL_KEY::COUNT, QStringLiteral("count")},
+                                                     {MODEL_KEY::SORTBY, QStringLiteral("sortby")},
+                                                     {MODEL_KEY::USER, QStringLiteral("user")},
+                                                     {MODEL_KEY::PASSWORD, QStringLiteral("password")},
+                                                     {MODEL_KEY::SERVER, QStringLiteral("server")},
+                                                     {MODEL_KEY::FOLDERSFIRST, QStringLiteral("foldersfirst")},
+                                                     {MODEL_KEY::VIEWTYPE, QStringLiteral("viewtype")},
+                                                     {MODEL_KEY::ADDDATE, QStringLiteral("adddate")},
+                                                     {MODEL_KEY::FAV, QStringLiteral("fav")},
+                                                     {MODEL_KEY::FAVORITE, QStringLiteral("favorite")},
+                                                     {MODEL_KEY::COLOR, QStringLiteral("color")},
+                                                     {MODEL_KEY::RATE, QStringLiteral("rate")},
+                                                     {MODEL_KEY::FORMAT, QStringLiteral("format")},
+                                                     {MODEL_KEY::PLACE, QStringLiteral("place")},
+                                                     {MODEL_KEY::LOCATION, QStringLiteral("location")},
+                                                     {MODEL_KEY::ALBUM, QStringLiteral("album")},
+                                                     {MODEL_KEY::DURATION, QStringLiteral("duration")},
+                                                     {MODEL_KEY::RELEASEDATE, QStringLiteral("releasedate")},
+                                                     {MODEL_KEY::ARTIST, QStringLiteral("artist")},
+                                                     {MODEL_KEY::LYRICS, QStringLiteral("lyrics")},
+                                                     {MODEL_KEY::TRACK, QStringLiteral("track")},
+                                                     {MODEL_KEY::GENRE, QStringLiteral("genre")},
+                                                     {MODEL_KEY::WIKI, QStringLiteral("wiki")},
+                                                     {MODEL_KEY::CONTEXT, QStringLiteral("context")},
+                                                     {MODEL_KEY::SOURCETYPE, QStringLiteral("sourcetype")},
+                                                     {MODEL_KEY::ARTWORK, QStringLiteral("artwork")},
+                                                     {MODEL_KEY::NOTE, QStringLiteral("note")},
+                                                     {MODEL_KEY::MOOD, QStringLiteral("mood")},
+                                                     {MODEL_KEY::COMMENT, QStringLiteral("comment")},
+                                                     {MODEL_KEY::PLAYLIST, QStringLiteral("playlist")},
+                                                     {MODEL_KEY::SOURCE, QStringLiteral("source")},
+                                                     {MODEL_KEY::TITLE, QStringLiteral("title")},
+                                                     {MODEL_KEY::ID, QStringLiteral("id")},
+                                                     {MODEL_KEY::PERSON_ID, QStringLiteral("personid")},
+                                                     {MODEL_KEY::PARENT_ID, QStringLiteral("parentid")},
+                                                     {MODEL_KEY::LICENSE, QStringLiteral("license")},
+                                                     {MODEL_KEY::DESCRIPTION, QStringLiteral("description")},
+                                                     {MODEL_KEY::BOOKMARK, QStringLiteral("bookmark")},
+                                                     {MODEL_KEY::ACCOUNT, QStringLiteral("account")},
+                                                     {MODEL_KEY::ACCOUNTTYPE, QStringLiteral("accounttype")},
+                                                     {MODEL_KEY::VERSION, QStringLiteral("version")},
+                                                     {MODEL_KEY::DOMAIN_M, QStringLiteral("domain")},
+                                                     {MODEL_KEY::CATEGORY, QStringLiteral("category")},
+                                                     {MODEL_KEY::CONTENT, QStringLiteral("content")},
+                                                     {MODEL_KEY::PIN, QStringLiteral("pin")},
+                                                     {MODEL_KEY::IMG, QStringLiteral("img")},
+                                                     {MODEL_KEY::PREVIEW, QStringLiteral("preview")},
+                                                     {MODEL_KEY::LINK, QStringLiteral("link")},
+                                                     {MODEL_KEY::STAMP, QStringLiteral("stamp")},
+                                                     {MODEL_KEY::BOOK, QStringLiteral("book")},
 
                                                      /** ccdav keys **/
-                                                     {MODEL_KEY::N, "n"},
-                                                     {MODEL_KEY::IM, "im"},
-                                                     {MODEL_KEY::PHOTO, "photo"},
-                                                     {MODEL_KEY::GENDER, "gender"},
-                                                     {MODEL_KEY::ADR, "adr"},
-                                                     {MODEL_KEY::ADR_2, "adr2"},
-                                                     {MODEL_KEY::ADR_3, "adr3"},
-                                                     {MODEL_KEY::EMAIL, "email"},
-                                                     {MODEL_KEY::EMAIL_2, "email2"},
-                                                     {MODEL_KEY::EMAIL_3, "email3"},
-                                                     {MODEL_KEY::LANG, "lang"},
-                                                     {MODEL_KEY::NICKNAME, "nickname"},
-                                                     {MODEL_KEY::ORG, "org"},
-                                                     {MODEL_KEY::PROFILE, "profile"},
-                                                     {MODEL_KEY::TZ, "tz"},
-                                                     {MODEL_KEY::TEL, "tel"},
-                                                     {MODEL_KEY::TEL_2, "tel2"},
-                                                     {MODEL_KEY::TEL_3, "tel3"},
+                                                     {MODEL_KEY::N, QStringLiteral("n")},
+                                                     {MODEL_KEY::IM, QStringLiteral("im")},
+                                                     {MODEL_KEY::PHOTO, QStringLiteral("photo")},
+                                                     {MODEL_KEY::GENDER, QStringLiteral("gender")},
+                                                     {MODEL_KEY::ADR, QStringLiteral("adr")},
+                                                     {MODEL_KEY::ADR_2, QStringLiteral("adr2")},
+                                                     {MODEL_KEY::ADR_3, QStringLiteral("adr3")},
+                                                     {MODEL_KEY::EMAIL, QStringLiteral("email")},
+                                                     {MODEL_KEY::EMAIL_2, QStringLiteral("email2")},
+                                                     {MODEL_KEY::EMAIL_3, QStringLiteral("email3")},
+                                                     {MODEL_KEY::LANG, QStringLiteral("lang")},
+                                                     {MODEL_KEY::NICKNAME, QStringLiteral("nickname")},
+                                                     {MODEL_KEY::ORG, QStringLiteral("org")},
+                                                     {MODEL_KEY::PROFILE, QStringLiteral("profile")},
+                                                     {MODEL_KEY::TZ, QStringLiteral("tz")},
+                                                     {MODEL_KEY::TEL, QStringLiteral("tel")},
+                                                     {MODEL_KEY::TEL_2, QStringLiteral("tel2")},
+                                                     {MODEL_KEY::TEL_3, QStringLiteral("tel3")},
 
-                                                     {MODEL_KEY::CITY, "city"},
-                                                     {MODEL_KEY::STATE, "state"},
-                                                     {MODEL_KEY::COUNTRY, "country"},
+                                                     {MODEL_KEY::CITY, QStringLiteral("city")},
+                                                     {MODEL_KEY::STATE, QStringLiteral("state")},
+                                                     {MODEL_KEY::COUNTRY, QStringLiteral("country")},
 
                                                      // opendesktop keys
-                                                     {MODEL_KEY::PACKAGE_ARCH, "packagearch"},
-                                                     {MODEL_KEY::PACKAGE_TYPE, "packagetype"},
-                                                     {MODEL_KEY::GPG_FINGERPRINT, "gpgfingerprint"},
-                                                     {MODEL_KEY::GPG_SIGNATURE, "gpgsignature"},
-                                                     {MODEL_KEY::PACKAGE_NAME, "packagename"},
-                                                     {MODEL_KEY::PRICE, "price"},
-                                                     {MODEL_KEY::REPOSITORY, "repository"},
-                                                     {MODEL_KEY::TAGS, "tags"},
-                                                     {MODEL_KEY::WAY, "way"},
-                                                     {MODEL_KEY::PIC, "pic"},
-                                                     {MODEL_KEY::SMALL_PIC, "smallpic"},
-                                                     {MODEL_KEY::CHANGED, "changed"},
-                                                     {MODEL_KEY::COMMENTS, "comments"},
-                                                     {MODEL_KEY::CREATED, "created"},
-                                                     {MODEL_KEY::DETAIL_PAGE, "detailpage"},
-                                                     {MODEL_KEY::DETAILS, "details"},
-                                                     {MODEL_KEY::TOTAL_DOWNLOADS, "totaldownloads"},
-                                                     {MODEL_KEY::GHNS_EXCLUDED, "ghnsexcluded"},
-                                                     {MODEL_KEY::LANGUAGE, "language"},
-                                                     {MODEL_KEY::SCORE, "score"},
-                                                     {MODEL_KEY::SUMMARY, "summary"},
-                                                     {MODEL_KEY::TYPE_ID, "typeid"},
-                                                     {MODEL_KEY::TYPE_NAME, "typename"},
-                                                     {MODEL_KEY::XDG_TYPE, "xdgtype"},
+                                                     {MODEL_KEY::PACKAGE_ARCH, QStringLiteral("packagearch")},
+                                                     {MODEL_KEY::PACKAGE_TYPE, QStringLiteral("packagetype")},
+                                                     {MODEL_KEY::GPG_FINGERPRINT, QStringLiteral("gpgfingerprint")},
+                                                     {MODEL_KEY::GPG_SIGNATURE, QStringLiteral("gpgsignature")},
+                                                     {MODEL_KEY::PACKAGE_NAME, QStringLiteral("packagename")},
+                                                     {MODEL_KEY::PRICE, QStringLiteral("price")},
+                                                     {MODEL_KEY::REPOSITORY, QStringLiteral("repository")},
+                                                     {MODEL_KEY::TAGS, QStringLiteral("tags")},
+                                                     {MODEL_KEY::WAY, QStringLiteral("way")},
+                                                     {MODEL_KEY::PIC, QStringLiteral("pic")},
+                                                     {MODEL_KEY::SMALL_PIC, QStringLiteral("smallpic")},
+                                                     {MODEL_KEY::CHANGED, QStringLiteral("changed")},
+                                                     {MODEL_KEY::COMMENTS, QStringLiteral("comments")},
+                                                     {MODEL_KEY::CREATED, QStringLiteral("created")},
+                                                     {MODEL_KEY::DETAIL_PAGE, QStringLiteral("detailpage")},
+                                                     {MODEL_KEY::DETAILS, QStringLiteral("details")},
+                                                     {MODEL_KEY::TOTAL_DOWNLOADS, QStringLiteral("totaldownloads")},
+                                                     {MODEL_KEY::GHNS_EXCLUDED, QStringLiteral("ghnsexcluded")},
+                                                     {MODEL_KEY::LANGUAGE, QStringLiteral("language")},
+                                                     {MODEL_KEY::SCORE, QStringLiteral("score")},
+                                                     {MODEL_KEY::SUMMARY, QStringLiteral("summary")},
+                                                     {MODEL_KEY::TYPE_ID, QStringLiteral("typeid")},
+                                                     {MODEL_KEY::TYPE_NAME, QStringLiteral("typename")},
+                                                     {MODEL_KEY::XDG_TYPE, QStringLiteral("xdgtype")},
 
                                                      // file props
-                                                     {MODEL_KEY::SYMLINK, "symlink"},
-                                                     {MODEL_KEY::IS_SYMLINK, "issymlink"},
-                                                     {MODEL_KEY::LAST_READ, "lastread"},
-                                                     {MODEL_KEY::READABLE, "readable"},
-                                                     {MODEL_KEY::WRITABLE, "writeable"},
-                                                     {MODEL_KEY::IS_DIR, "isdir"},
-                                                     {MODEL_KEY::IS_FILE, "isfile"},
-                                                     {MODEL_KEY::IS_REMOTE, "isremote"},
-                                                     {MODEL_KEY::EXECUTABLE, "executable"},
-                                                     {MODEL_KEY::VALUE, "value"},
-                                                     {MODEL_KEY::KEY, "key"},
+                                                     {MODEL_KEY::SYMLINK, QStringLiteral("symlink")},
+                                                     {MODEL_KEY::IS_SYMLINK, QStringLiteral("issymlink")},
+                                                     {MODEL_KEY::LAST_READ, QStringLiteral("lastread")},
+                                                     {MODEL_KEY::READABLE, QStringLiteral("readable")},
+                                                     {MODEL_KEY::WRITABLE, QStringLiteral("writeable")},
+                                                     {MODEL_KEY::IS_DIR, QStringLiteral("isdir")},
+                                                     {MODEL_KEY::IS_FILE, QStringLiteral("isfile")},
+                                                     {MODEL_KEY::IS_REMOTE, QStringLiteral("isremote")},
+                                                     {MODEL_KEY::EXECUTABLE, QStringLiteral("executable")},
+                                                     {MODEL_KEY::VALUE, QStringLiteral("value")},
+                                                     {MODEL_KEY::KEY, QStringLiteral("key")},
 
-                                                     {MODEL_KEY::MAC, "mac"},
-                                                     {MODEL_KEY::LOT, "lot"},
-                                                     {MODEL_KEY::APP, "app"},
-                                                     {MODEL_KEY::URI, "uri"},
-                                                     {MODEL_KEY::DEVICE, "device"},
-                                                     {MODEL_KEY::UDI, "udi"},
-                                                     {MODEL_KEY::LASTSYNC, "lastsync"},
-                                                     {MODEL_KEY::LATITUDE, "latitude"},
-                                                     {MODEL_KEY::BRANCH, "branch"},
-                                                     {MODEL_KEY::MESSAGE, "message"},
-                                                     {MODEL_KEY::AUTHOR, "author"},
-                                                     {MODEL_KEY::UPDATABLE, "updatable"},
-                                                     {MODEL_KEY::LONGITUDE, "lastsync"}};
+                                                     {MODEL_KEY::MAC, QStringLiteral("mac")},
+                                                     {MODEL_KEY::LOT, QStringLiteral("lot")},
+                                                     {MODEL_KEY::APP, QStringLiteral("app")},
+                                                     {MODEL_KEY::URI, QStringLiteral("uri")},
+                                                     {MODEL_KEY::DEVICE, QStringLiteral("device")},
+                                                     {MODEL_KEY::UDI, QStringLiteral("udi")},
+                                                     {MODEL_KEY::LASTSYNC, QStringLiteral("lastsync")},
+                                                     {MODEL_KEY::LATITUDE, QStringLiteral("latitude")},
+                                                     {MODEL_KEY::BRANCH, QStringLiteral("branch")},
+                                                     {MODEL_KEY::MESSAGE, QStringLiteral("message")},
+                                                     {MODEL_KEY::AUTHOR, QStringLiteral("author")},
+                                                     {MODEL_KEY::UPDATABLE, QStringLiteral("updatable")},
+                                                     {MODEL_KEY::LONGITUDE, QStringLiteral("lastsync")}};
                                                      
 static const QHash<QString, MODEL_KEY> MODEL_NAME_KEY = {{MODEL_NAME[MODEL_KEY::ICON], MODEL_KEY::ICON},
                                                          {MODEL_NAME[MODEL_KEY::LABEL], MODEL_KEY::LABEL},
@@ -612,5 +611,3 @@ bool MAUIKIT_EXPORT fileExists(const QUrl &path);
 
 
 }
-
-#endif // FMH_H
